import logging
from suds.client import Client
from suds.transport.http import HttpAuthenticated

class Urls:
    pass

class Magentouch:
    def __init__(self, **kwargs):
        if 'url' not in kwargs.keys():
            self.complain(self.parameter_error, 'url')

        self.__dict__.update(kwargs)

        t = HttpAuthenticated(username=self.username, password=self.password)
        #self.client = Client(self.url, transport=t)
        self.client = Client(self.url)
        self.service = self.client.service
        self.session = self.service.login(self.username, self.password)

    def complain(self, func, reason):
        func(reason)
        
    def parameter_error(self, par):
        print 'missing or incorrect parameter {} provided.'
        print 'available paramters to initialize the class'
        print 'are: url, [username], [password]'
        raise ValueError()

    def login(self, **kwargs):
        if kwargs:
            self.__dict__.update(kwargs)
        try:
            self.service.login(self.username, self.password)
        except KeyError:
            self.complain(self.parameter_error, 'username, password')
    def get_client(self):
        return self.client



from suds.sudsobject import asdict

def recursive_asdict(d):
    """Convert Suds object into serializable format."""
    out = {}
    for k, v in asdict(d).iteritems():
        if hasattr(v, '__keylist__'):
            out[k] = recursive_asdict(v)
        elif isinstance(v, list):
            out[k] = []
            for item in v:
                if hasattr(item, '__keylist__'):
                    out[k].append(recursive_asdict(item))
                else:
                    out[k].append(item)
        else:
            out[k] = v
    return out

def suds_to_json(data):
    return json.dumps(recursive_asdict(data))



#from distutils.core import setup
from setuptools import setup
setup(name='magentouch',
      version='1.0',
      description='Magento Soup v2 suds client',
      author='Jacob CUI',
      author_email='jacobcui123@gmail.com',
      url='https://github.com/jacobcui/magentouch',
      packages=['magentouch'],
      install_requires=['suds'],
      license='GPL',
     )
